@@ -35,6 +35,9 @@ hiredis = ffi.verify("""
 class HiredisError(Exception):
     pass
 
+class NoReply(HiredisError):
+    pass
+
 class RedisReader(object):
     "Hiredis wrapper"
 
@@ -84,12 +87,12 @@ class RedisReader(object):
         reply_pointer = ffi.new("redisReply * *")
         res = hiredis.redisReaderGetReply(self.hiredis, reply_pointer)
         if res == self.REDIS_ERR:
-            raise RedisError("Error parsing")
+            raise HiredisError("Error parsing")
 
         reply = reply_pointer[0]
         if reply:
             gc_reply = ffi.gc(reply, hiredis.freeReplyObject)
             return self.to_py(gc_reply)
         else:
-            return False
+            raise NoReply()
 
